==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesSs.php <==
<?php
/** Swati (SiSwati)
 *
 * @ingroup Language
 * @file
 *
 * @author Jatrobat
 * @author MF-Warburg
 */

$messages = array(
# Dates
'sunday'        => 'LíSontfo',
'monday'        => 'uMsombulûko',
'tuesday'       => 'Lesíbilí',
'wednesday'     => 'Lésitsâtfu',
'thursday'      => 'Lesíne',
'friday'        => 'Lesíhlánu',
'saturday'      => 'úMgcibélo',
'january'       => 'Bhimbídvwane',
'february'      => 'iNdlóvana',
'march'         => 'íNdlovu',
'april'         => 'Mábasa',
'may_long'      => 'íNkhwekhwéti',
'june'          => 'íNhlaba',
'july'          => 'Khólwáne',
'august'        => 'íNgci',
'september'     => 'íNyoni',
'october'       => 'íMphala',
'november'      => 'Lídvúba',
'december'      => 'íNgongóni',
'january-gen'   => 'Bhimbídvwane',
'february-gen'  => 'iNdlóvana',
'march-gen'     => 'íNdlovu',
'april-gen'     => 'Mábasa',
'may-gen'       => 'íNkhwekhwéti',
'june-gen'      => 'íNhlaba',
'july-gen'      => 'Khólwáne',
'august-gen'    => 'íNgci',
'september-gen' => 'íNyoni',
'october-gen'   => 'íMphala',
'november-gen'  => 'Lídvúba',
'december-gen'  => 'íNgongóni',

'qbfind'         => 'Kúkhándza',
'qbedit'         => 'Kúhlela',
'qbspecialpages' => 'Emakhasi labalulekile',

'help'             => 'Kúsíta',
'search'           => 'Kucálata',
'searchbutton'     => 'kucálata',
'go'               => 'Kúhámba',
'searcharticle'    => 'Kúhámba',
'history_short'    => 'Umlandvo',
'print'            => 'Kucindzetêla',
'edit'             => 'kúhlela',
'talkpagelinktext' => 'Kúcoca',
'talk'             => 'Kúcoca',
'jumptosearch'     => 'kucálata',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'Likhasi Lelikhulu',
'mainpage-description' => 'Likhasi Lelikhulu',
'portal'               => 'Likhefi leinthanethi',
'portal-url'           => 'Project:Likhefi leinthanethi',

'youhavenewmessages' => 'Ube $1 ($2).',
'editsection'        => 'kúhlela',
'editold'            => 'kúhlela',
'viewdeleted'        => 'Kúfúna $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Intfo',
'nstab-user' => 'Umuntfu',
'nstab-help' => 'Kúsíta',

# Login and logout pages
'uid'                => 'Umuntfu ID:',
'yourlanguage'       => 'Lúlwîmi:',
'loginlanguagelabel' => 'Lúlwîmi: $1',

# Search results
'powersearch' => 'Kucálata',

# Preferences page
'searchresultshead' => 'Kucálata',

# Special:ImageList
'imagelist_date' => 'Lusuku',
'imagelist_name' => 'Ligama',
'imagelist_user' => 'Umuntfu',

# Image description page
'filehist-datetime' => 'Lusuku/Síkhatsí',
'filehist-user'     => 'Umuntfu',

'brokenredirects-edit' => '(kúhlela)',

'withoutinterwiki-submit' => 'Kúfúna',

# Miscellaneous special pages
'move' => 'Kúgojotîsa',

# Book sources
'booksources-go' => 'Kúhámba',

# Special:Log
'specialloguserlabel' => 'Umuntfu:',
'log-search-submit'   => 'Kúhámba',

# Special:AllPages
'allpagessubmit' => 'Kúhámba',

# Special:ListUsers
'listusers-submit' => 'Kúfúna',

# Watchlist
'watch'   => 'Gadza',
'unwatch' => 'Yekela kugadza',

# Restrictions (nouns)
'restriction-edit'   => 'Kúhlela',
'restriction-move'   => 'Kúgojotîsa',
'restriction-create' => 'Kúdála',

# Undelete
'undelete-search-submit' => 'Kucálata',

'sp-contributions-submit' => 'Kucálata',

# Block/unblock
'ipblocklist-submit' => 'Kucálata',
'proxyblocksuccess'  => 'Ngiénta.',

# Move page
'movelogpage' => 'Kúgojotîsa log',

# Namespace 8 related
'allmessagesname' => 'Ligama',

# Tooltip help for the actions
'tooltip-search' => 'Kucálata {{SITENAME}}',
'tooltip-p-logo' => 'Likhasi Lelikhulu',

# Special:NewImages
'ilsubmit' => 'Kucálata',

# Multipage image navigation
'imgmultigo' => 'Kúhámba!',

# Table pager
'table_pager_limit_submit' => 'Kúhámba',

# Special:Version
'version-specialpages' => 'Emakhasi labalulekile',

# Special:SpecialPages
'specialpages' => 'Emakhasi labalulekile',

);

==> mediawiki-1.15.0rc1.tar.gz: mediawiki-1.15.0rc1/languages/messages/MessagesSs.php <==
<?php
/** Swati (SiSwati)
 *
 * @ingroup Language
 * @file
 *
 * @author Jatrobat
 * @author MF-Warburg
 */

$messages = array(
# Dates
'sunday'        => 'LíSontfo',
'monday'        => 'uMsombulûko',
'tuesday'       => 'Lesíbilí',
'wednesday'     => 'Lésitsâtfu',
'thursday'      => 'Lesíne',
'friday'        => 'Lesíhlánu',
'saturday'      => 'úMgcibélo',
'january'       => 'Bhimbídvwane',
'february'      => 'iNdlóvana',
'march'         => 'íNdlovu',
'april'         => 'Mábasa',
'may_long'      => 'íNkhwekhwéti',
'june'          => 'íNhlaba',
'july'          => 'Khólwáne',
'august'        => 'íNgci',
'september'     => 'íNyoni',
'october'       => 'íMphala',
'november'      => 'Lídvúba',
'december'      => 'íNgongóni',
'january-gen'   => 'Bhimbídvwane',
'february-gen'  => 'iNdlóvana',
'march-gen'     => 'íNdlovu',
'april-gen'     => 'Mábasa',
'may-gen'       => 'íNkhwekhwéti',
'june-gen'      => 'íNhlaba',
'july-gen'      => 'Khólwáne',
'august-gen'    => 'íNgci',
'september-gen' => 'íNyoni',
'october-gen'   => 'íMphala',
'november-gen'  => 'Lídvúba',
'december-gen'  => 'íNgongóni',

'qbfind'         => 'Kúkhándza',
'qbedit'         => 'Kúhlela',
'qbspecialpages' => 'Emakhasi labalulekile',

'help'             => 'Kúsíta',
'search'           => 'Kucálata',
'searchbutton'     => 'kucálata',
'go'               => 'Kúhámba',
'searcharticle'    => 'Kúhámba',
'history_short'    => 'Umlandvo',
'print'            => 'Kucindzetêla',
'edit'             => 'kúhlela',
'talkpagelinktext' => 'Kúcoca',
'talk'             => 'Kúcoca',
'jumptosearch'     => 'kucálata',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'Likhasi Lelikhulu',
'mainpage-description' => 'Likhasi Lelikhulu',
'portal'               => 'Likhefi leinthanethi',
'portal-url'           => 'Project:Likhefi leinthanethi',

'youhavenewmessages' => 'Ube $1 ($2).',
'editsection'        => 'kúhlela',
'editold'            => 'kúhlela',
'viewdeleted'        => 'Kúfúna $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Intfo',
'nstab-user' => 'Umuntfu',
'nstab-help' => 'Kúsíta',

# Login and logout pages
'uid'                => 'Umuntfu ID:',
'yourlanguage'       => 'Lúlwîmi:',
'loginlanguagelabel' => 'Lúlwîmi: $1',

# Search results
'powersearch' => 'Kucálata',

# Preferences page
'searchresultshead' => 'Kucálata',

# Special:ListFiles
'listfiles_date' => 'Lusuku',
'listfiles_name' => 'Ligama',
'listfiles_user' => 'Umuntfu',

# File description page
'filehist-datetime' => 'Lusuku/Síkhatsí',
'filehist-user'     => 'Umuntfu',

'brokenredirects-edit' => '(kúhlela)',

'withoutinterwiki-submit' => 'Kúfúna',

# Miscellaneous special pages
'move' => 'Kúgojotîsa',

# Book sources
'booksources-go' => 'Kúhámba',

# Special:Log
'specialloguserlabel' => 'Umuntfu:',

# Special:AllPages
'allpagessubmit' => 'Kúhámba',

# Special:LinkSearch
'linksearch-ok' => 'Kucálata',

# Special:ListUsers
'listusers-submit' => 'Kúfúna',

# Watchlist
'watch'   => 'Gadza',
'unwatch' => 'Yekela kugadza',

# Restrictions (nouns)
'restriction-edit'   => 'Kúhlela',
'restriction-move'   => 'Kúgojotîsa',
'restriction-create' => 'Kúdála',

# Undelete
'undelete-search-submit' => 'Kucálata',

'sp-contributions-submit' => 'Kucálata',

# Block/unblock
'ipblocklist-submit' => 'Kucálata',
'proxyblocksuccess'  => 'Ngiénta.',

# Move page
'movelogpage' => 'Kúgojotîsa log',

# Namespace 8 related
'allmessagesname' => 'Ligama',

# Tooltip help for the actions
'tooltip-search' => 'Kucálata {{SITENAME}}',
'tooltip-p-logo' => 'Likhasi Lelikhulu',

# Special:NewFiles
'ilsubmit' => 'Kucálata',

# Multipage image navigation
'imgmultigo' => 'Kúhámba!',

# Table pager
'table_pager_limit_submit' => 'Kúhámba',

# Special:Version
'version-specialpages' => 'Emakhasi labalulekile',

# Special:SpecialPages
'specialpages' => 'Emakhasi labalulekile',

);
